@@ -1,21 +1,17 @@
-from .payeeaddress import PayeeAddress
-from .subaccount import SubAccount
-
-
 class Split:
     def __init__(self):
-        self.payee: str or None = None
-        self.memo: str or None = None
-        self.shares: str or None = None
-        self.number: str or None = None
-        self.action: str or None = None
-        self.price: str or None = None
-        self.account: str or None = None
-        self.reconcileFlag: str or None = None
-        self.bankId: str or None = None
-        self.value: str or None = None
-        self.reconcileDate: str or None = None
-        self.id: str or None = None
+        self.payee: str = ""
+        self.memo: str = ""
+        self.shares: str = ""
+        self.number: str = ""
+        self.action: str = ""
+        self.price: str = ""
+        self.account: str = ""
+        self.reconcileFlag: str = ""
+        self.bankId: str = ""
+        self.value: str = ""
+        self.reconcileDate: str = ""
+        self.id: str = ""
 
     @classmethod
     def from_xml(cls, node):
