@@ -3,9 +3,9 @@ from .useraddress import UserAddress
 
 class User(object):
     def __init__(self):
-        self.email: str or None = None
-        self.name: str or None = None
-        self.address: UserAddress or None = None
+        self.email: str = ""
+        self.name: str = ""
+        self.address: UserAddress = UserAddress()
 
     @classmethod
     def from_xml(cls, node):
