@@ -4,8 +4,8 @@ from .address import Address
 class UserAddress(Address):
     def __init__(self):
         super().__init__()
-        self.zipcode: str or None = None
-        self.county: str or None = None
+        self.zipcode: str = ""
+        self.county: str = ""
 
     @classmethod
     def from_xml(cls, node):
@@ -17,4 +17,3 @@ class UserAddress(Address):
         super().init_from_xml(node)
         self.zipcode = node.attrib['zipcode']
         self.county = node.attrib['county']
-
